(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     79940,       1746]
NotebookOptionsPosition[     79521,       1727]
NotebookOutlinePosition[     79864,       1743]
CellTagsIndexPosition[     79821,       1740]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Financial", " ", "Modelling", " ", "using", " ", "the", " ", "Vector", 
    " ", "method", " ", "with", " ", "Solve"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"timestart", "=", 
     RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"periods", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"periods", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"assignElementsFull", ",", "Prev"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"For", " ", "assignElementsFull", " ", "refer", " ", 
     RowBox[{"to", " ", "[", "mg110241", "]"}], " ", 
     RowBox[{"Re", ":", 
      RowBox[{
      "Programatically", " ", "creating", " ", "delayed", " ", "assignment", 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"http", ":"}], "//", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"forums", ".", "wolfram", ".", "com"}], "/", 
              "mathgroup"}], "/", "archive"}], "/", "2010"}], "/", "Jun"}], 
          "/", 
          RowBox[{"msg00136", ".", "html"}]}]}], ")"}]}]}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"assignElementsFull", "[", 
      RowBox[{"name_String", ",", "elemName_String", ",", "length_Integer"}], 
      "]"}], ":=", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"heldName", "=", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"name", ",", "InputForm", ",", "Hold"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{
        RowBox[{"Clear", "@@", "heldName"}], ";", "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"heldElementBaseName", "=", 
            RowBox[{"ToExpression", "[", 
             RowBox[{
              RowBox[{"elemName", "<>", "name"}], ",", "InputForm", ",", 
              "Hold"}], "]"}]}], "}"}], ",", 
          RowBox[{"Block", "@@", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"Map", "[", 
              RowBox[{"List", ",", "heldElementBaseName"}], "]"}], ",", 
             RowBox[{"Unevaluated", "[", 
              RowBox[{
               RowBox[{"Evaluate", "[", 
                RowBox[{"First", "@", "heldName"}], "]"}], ":=", 
               RowBox[{"Evaluate", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"First", "[", "heldElementBaseName", "]"}], "[", 
                   "i", "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "length"}], "}"}]}], "]"}], "]"}]}], 
              "]"}]}], "]"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Prev", "[", "vec_", "]"}], ":=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"First", "[", "vec", "]"}], ",", 
        RowBox[{"Most", "[", "vec", "]"}]}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"establish", " ", "the", " ", "variable", " ", "vectors"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns", "=", 
     RowBox[{"Hold", "[", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"**", " ", "Projection"}], " ", "assumptions"}], " ", 
       "***)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"salesgrowthrate", "\[Equal]", 
        RowBox[{"Prev", "[", "salesgrowthrate", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"expensesgrowthrate", "\[Equal]", 
        RowBox[{"Prev", "[", "expensesgrowthrate", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"newloan", "\[Equal]", 
        RowBox[{"Prev", "[", "newloan", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"newcapital", "\[Equal]", 
        RowBox[{"Prev", "[", "newcapital", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"newassets", "\[Equal]", 
        RowBox[{"Prev", "[", "depreciation", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"depreciationrate", "\[Equal]", 
        RowBox[{"Prev", "[", "depreciationrate", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"loanintrate", "\[Equal]", 
        RowBox[{"Prev", "[", "loanintrate", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"netcashintrate", "\[Equal]", 
        RowBox[{"Prev", "[", "netcashintrate", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"taxrate", "\[Equal]", 
        RowBox[{"Prev", "[", "taxrate", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"daysdebtors", "\[Equal]", 
        RowBox[{"Prev", "[", "daysdebtors", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"daysstock", "\[Equal]", 
        RowBox[{"Prev", "[", "daysstock", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"dayscreditors", "\[Equal]", 
        RowBox[{"Prev", "[", "dayscreditors", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"divpayoutratio", "\[Equal]", 
        RowBox[{"Prev", "[", "divpayoutratio", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"interimdivpropn", "\[Equal]", 
        RowBox[{"Prev", "[", "interimdivpropn", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"interimprofitpropn", "\[Equal]", 
        RowBox[{"Prev", "[", "interimprofitpropn", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"interimnewcapitalpropn", "\[Equal]", 
        RowBox[{"Prev", "[", "interimnewcapitalpropn", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"interimnewloanpropn", "\[Equal]", 
        RowBox[{"Prev", "[", "interimnewloanpropn", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"interimnewassetspropn", "\[Equal]", 
        RowBox[{"Prev", "[", "interimnewassetspropn", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", " ", "MAIN"}], " ", "MODEL"}], " ", "***)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"*", " ", "P"}], "&"}], "L"}], " ", "**)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"sales", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "sales", "]"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", "salesgrowthrate"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"expenses", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "expenses", "]"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", "expensesgrowthrate"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"start", " ", "of", " ", "interest", " ", "calculation"}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"first", " ", "half"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"intloan1", "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Prev", "[", "loan", "]"}], "/", "2"}], "+", 
           RowBox[{"newloan", " ", 
            RowBox[{"interimnewloanpropn", "/", "4"}]}]}], ")"}], 
         "loanintrate"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"intcf1", "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"collections", "-", "payments"}], ")"}], 
          "interimprofitpropn"}], "+", 
         RowBox[{"newcapital", " ", "interimnewcapitalpropn"}], "+", 
         RowBox[{"newloan", " ", "interimnewloanpropn"}], "-", " ", 
         RowBox[{"newassets", " ", "interimnewassetspropn"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "earnings", " ", "before", " ", "interest", " ", "on", " ", "cash", 
         " ", "and", " ", "after", " ", "interest", " ", "on", " ", "loans"}],
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{"deprec1", "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Prev", "[", "netfixedassets", "]"}], "/", "2"}], "+", 
           RowBox[{"newassets", " ", 
            RowBox[{"interimnewassetspropn", "/", "4"}]}]}], ")"}], 
         "depreciationrate"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"ebcit1", "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"sales", "-", "expenses"}], ")"}], "interimprofitpropn"}], 
         "-", "deprec1", "-", "intloan1"}]}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
          "The", " ", "folowing", " ", "equations", " ", "solve", " ", "the", 
           " ", "circular", " ", "loop", " ", "\[IndentingNewLine]", 
           RowBox[{"cash1", "[", "t", "]"}]}], "\[Equal]", 
          RowBox[{
           RowBox[{"cash", "[", 
            RowBox[{"t", "-", "1"}], "]"}], "+", 
           RowBox[{"intcf1", "[", "t", "]"}], "+", 
           RowBox[{"intcash1", "[", "t", "]"}], "-", 
           RowBox[{"taxpmt1", "[", "t", "]"}]}]}], ",", "\[IndentingNewLine]",
          "or", ",", " ", 
         RowBox[{
          RowBox[{"cash1", "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{"cash", "[", 
            RowBox[{"t", "-", "1"}], "]"}], "+", 
           RowBox[{"intcf1", "[", "t", "]"}], "-", 
           RowBox[{"intloan1", "[", "t", "]"}], "+", 
           RowBox[{"intcash1", "[", "t", "]"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ebcit1", "[", "t", "]"}], "+", 
              RowBox[{"intcash1", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
           RowBox[{
            RowBox[{"provdiv", "[", 
             RowBox[{"t", "-", "1"}], "]"}], " ", 
            RowBox[{"(", "1", ")"}]}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"and", " ", 
           RowBox[{"intcash1", "[", "t", "]"}]}], "\[Equal]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"cash", "[", 
              RowBox[{"t", "-", "1"}], "]"}], "+", 
             RowBox[{"cash1", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"cashintrate", "[", "t", "]"}], "/", "4"}], " ", 
           RowBox[{"(", "2", ")"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", "1", ")"}], "in", 
          RowBox[{"(", "2", ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"intcash1", "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"cash", "[", 
              RowBox[{"t", "-", "1"}], "]"}], "+", 
             RowBox[{"cash", "[", 
              RowBox[{"t", "-", "1"}], "]"}], "+", 
             RowBox[{"intcf1", "[", "t", "]"}], "-", 
             RowBox[{"intloan1", "[", "t", "]"}], "+", 
             RowBox[{"intcash1", "[", "t", "]"}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ebcit1", "[", "t", "]"}], "+", 
                RowBox[{"intcash1", "[", "t", "]"}]}], ")"}], "*", 
              RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
             RowBox[{"provdiv", "[", 
              RowBox[{"t", "-", "1"}], "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"cashintrate", "[", "t", "]"}], "/", "4"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             RowBox[{"intcash1", "[", "t", "]"}]}], ")"}], "/", 
           RowBox[{"cashintrate", "[", "t", "]"}]}], "\[Equal]", 
          RowBox[{
           RowBox[{"cash", "[", 
            RowBox[{"t", "-", "1"}], "]"}], "+", 
           RowBox[{"cash", "[", 
            RowBox[{"t", "-", "1"}], "]"}], "+", 
           RowBox[{"intcf1", "[", "t", "]"}], "-", 
           RowBox[{"intloan1", "[", "t", "]"}], "+", 
           RowBox[{"intcash1", "[", "t", "]"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ebcit1", "[", "t", "]"}], "+", 
              RowBox[{"intcash1", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
           RowBox[{"provdiv", "[", 
            RowBox[{"t", "-", "1"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"intcash1", "[", "t", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "/", 
               RowBox[{"cashintrate", "[", "t", "]"}]}], ")"}], "-", "1", "+", 
             RowBox[{"taxrate", "[", "t", "]"}]}], ")"}]}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"cash", "[", 
             RowBox[{"t", "-", "1"}], "]"}]}], "+", 
           RowBox[{"intcf1", "[", "t", "]"}], "-", 
           RowBox[{"intloan1", "[", "t", "]"}], "-", 
           RowBox[{
            RowBox[{"ebcit1", "[", "t", "]"}], "*", 
            RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
           RowBox[{"provdiv", "[", 
            RowBox[{"t", "-", "1"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"intcash1", "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"cash", "[", 
               RowBox[{"t", "-", "1"}], "]"}]}], "+", 
             RowBox[{"intcf1", "[", "t", "]"}], "-", 
             RowBox[{"intloan1", "[", "t", "]"}], "-", 
             RowBox[{
              RowBox[{"ebcit1", "[", "t", "]"}], "*", 
              RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
             RowBox[{"provdiv", "[", 
              RowBox[{"t", "-", "1"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "/", 
               RowBox[{"cashintrate", "[", "t", "]"}]}], ")"}], "-", "1", "+", 
             RowBox[{"taxrate", "[", "t", "]"}]}], ")"}]}]}], ","}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"intcash1", "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"Prev", "[", "netcash", "]"}]}], "+", "intcf1", "-", 
           "intloan1", "-", 
           RowBox[{"ebcit1", "*", "taxrate"}], "-", 
           RowBox[{"Prev", "[", "provdiv", "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "/", "netcashintrate"}], ")"}], "-", "1", "+", 
           "taxrate"}], ")"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"taxpmt1", "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ebcit1", "+", "intcash1"}], ")"}], "taxrate"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"netcash1", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "netcash", "]"}], "+", "intcf1", "+", 
         "intcash1", "-", "taxpmt1"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"second", " ", "half"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"intloan2", "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Prev", "[", "loan", "]"}], "/", "2"}], "+", 
           RowBox[{"newloan", " ", 
            RowBox[{"interimnewloanpropn", "/", "2"}]}], "+", 
           RowBox[{"newloan", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "interimnewloanpropn"}], ")"}], "/", 
             "4"}]}]}], ")"}], "loanintrate"}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"intcf2", "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"collections", "-", "payments"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", "interimprofitpropn"}], ")"}]}], "+", 
         RowBox[{"newcapital", 
          RowBox[{"(", 
           RowBox[{"1", "-", "interimnewcapitalpropn"}], ")"}]}], "+", 
         RowBox[{"newloan", 
          RowBox[{"(", 
           RowBox[{"1", "-", "interimnewloanpropn"}], ")"}]}], "-", 
         RowBox[{"newassets", 
          RowBox[{"(", 
           RowBox[{"1", "-", "interimnewassetspropn"}], ")"}]}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"deprec2", "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Prev", "[", "netfixedassets", "]"}], "/", "2"}], "+", 
           RowBox[{"newassets", " ", 
            RowBox[{"interimnewassetspropn", "/", "2"}]}], "+", 
           RowBox[{"newassets", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "interimnewassetspropn"}], ")"}], "/", 
             "4"}]}]}], ")"}], "depreciationrate"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ebcit2", "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"sales", "-", "expenses"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", "interimprofitpropn"}], ")"}]}], "-", "deprec2", 
         "-", "intloan2"}]}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{" ", 
           RowBox[{
            RowBox[{"Solve", ":", " ", 
             RowBox[{
              RowBox[{"cash2", "[", "t", "]"}], "\[Equal]", 
              RowBox[{
               RowBox[{"cash1", "[", "t", "]"}], "+", 
               RowBox[{"intcf2", "[", "t", "]"}], "-", 
               RowBox[{"intloan2", "[", "t", "]"}], "+", 
               RowBox[{"intcash2", "[", "t", "]"}], "-", 
               RowBox[{"taxpmt2", "[", "t", "]"}], "-", 
               RowBox[{"div2", "[", "t", "]"}]}]}]}], ",", 
            "\[IndentingNewLine]", "or", ",", "     ", 
            RowBox[{
             RowBox[{"cash2", "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"cash1", "[", "t", "]"}], "+", 
              RowBox[{"intcf2", "[", "t", "]"}], "-", 
              RowBox[{"intloan2", "[", "t", "]"}], "+", 
              RowBox[{"intcash2", "[", "t", "]"}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ebcit2", "[", "t", "]"}], "+", 
                 RowBox[{"intcash2", "[", "t", "]"}]}], ")"}], "*", 
               RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ebcit1", "[", "t", "]"}], "+", 
                 RowBox[{"intcash1", "[", "t", "]"}], "+", 
                 RowBox[{"ebcit2", "[", "t", "]"}], "+", 
                 RowBox[{"intcash2", "[", "t", "]"}]}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"taxrate", "[", "t", "]"}]}], ")"}], "*", 
               RowBox[{"divpayoutrate", "[", "t", "]"}], "*", 
               RowBox[{"interimdivpropn", "[", "t", "]"}], " ", 
               RowBox[{"(", "1", ")"}]}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"and", "    ", 
              RowBox[{"intcash2", "[", "t", "]"}]}], "\[Equal]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"cash1", "[", "t", "]"}], "+", 
                RowBox[{"cash2", "[", "t", "]"}]}], ")"}], "*", 
              RowBox[{
               RowBox[{"cashintrate", "[", "t", "]"}], "/", "4"}], " ", 
              RowBox[{"(", "2", ")"}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"(", "1", ")"}], "in", 
             RowBox[{"(", "2", ")"}]}], ",", " ", 
            RowBox[{
             RowBox[{"intcash2", "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"cash1", "[", "t", "]"}], "+", 
                RowBox[{"cash1", "[", "t", "]"}], "+", 
                RowBox[{"intcf2", "[", "t", "]"}], "-", 
                RowBox[{"intloan2", "[", "t", "]"}], "+", 
                RowBox[{"intcash2", "[", "t", "]"}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"ebcit2", "[", "t", "]"}], "+", 
                   RowBox[{"intcash2", "[", "t", "]"}]}], ")"}], "*", 
                 RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"ebcit1", "[", "t", "]"}], "+", 
                   RowBox[{"intcash1", "[", "t", "]"}], "+", 
                   RowBox[{"ebcit2", "[", "t", "]"}], "+", 
                   RowBox[{"intcash2", "[", "t", "]"}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"taxrate", "[", "t", "]"}]}], ")"}], "*", 
                 RowBox[{"divpayoutratio", "[", "t", "]"}], "*", 
                 RowBox[{"interimdivpropn", "[", "t", "]"}]}]}], ")"}], "*", 
              RowBox[{"taxrate", "[", "t", "]"}]}]}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"cashintrate", "[", "t", "]"}], "/", "4"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", " ", 
             RowBox[{"intcash2", "[", "t", "]"}]}], ")"}], "/", 
           RowBox[{"cashintrate", "[", "t", "]"}]}], "\[Equal]", 
          RowBox[{
           RowBox[{"cash1", "[", "t", "]"}], "+", 
           RowBox[{"cash1", "[", "t", "]"}], "+", 
           RowBox[{"intcf2", "[", "t", "]"}], "-", 
           RowBox[{"intloan2", "[", "t", "]"}], "+", 
           RowBox[{"intcash2", "[", "t", "]"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ebcit2", "[", "t", "]"}], "+", 
              RowBox[{"intcash2", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ebcit1", "[", "t", "]"}], "+", 
              RowBox[{"intcash1", "[", "t", "]"}], "+", 
              RowBox[{"ebcit2", "[", "t", "]"}], "+", 
              RowBox[{"intcash2", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"taxrate", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{"divpayoutratio", "[", "t", "]"}], "*", 
            RowBox[{"interimdivpropn", "[", "t", "]"}]}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"intcash2", "[", "t", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "/", 
               RowBox[{"cashintrate", "[", "t", "]"}]}], ")"}], "-", "1", "+", 
             RowBox[{"taxrate", "[", "t", "]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"taxrate", "[", "t", "]"}]}], ")"}], "*", 
              RowBox[{"divpayoutratio", "[", "t", "]"}], "*", 
              RowBox[{"interimdivpropn", "[", "t", "]"}]}]}], ")"}]}], 
          "\[Equal]", " ", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"cash1", "[", "t", "]"}]}], "+", 
           RowBox[{"intcf2", "[", "t", "]"}], "-", 
           RowBox[{"intloan2", "[", "t", "]"}], "-", 
           RowBox[{
            RowBox[{"ebcit2", "[", "t", "]"}], "*", 
            RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ebcit1", "[", "t", "]"}], "+", 
              RowBox[{"intcash1", "[", "t", "]"}], "+", 
              RowBox[{"ebcit2", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"taxrate", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{"divpayoutratio", "[", "t", "]"}], "*", 
            RowBox[{"interimdivpropn", "[", "t", "]"}]}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"intcash2", "[", "t", "]"}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"cash1", "[", "t", "]"}]}], "+", 
             RowBox[{"intcf2", "[", "t", "]"}], "-", 
             RowBox[{"intloan2", "[", "t", "]"}], "-", 
             RowBox[{
              RowBox[{"ebcit2", "[", "t", "]"}], "*", 
              RowBox[{"taxrate", "[", "t", "]"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ebcit1", "[", "t", "]"}], "+", 
                RowBox[{"intcash1", "[", "t", "]"}], "+", 
                RowBox[{"ebcit2", "[", "t", "]"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"taxrate", "[", "t", "]"}]}], ")"}], "*", 
              RowBox[{"divpayoutratio", "[", "t", "]"}], "*", 
              RowBox[{"interimdivpropn", "[", "t", "]"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "/", 
               RowBox[{"cashintrate", "[", "t", "]"}]}], ")"}], "-", "1", "+", 
             RowBox[{"taxrate", "[", "t", "]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"taxrate", "[", "t", "]"}]}], ")"}], "*", 
              RowBox[{"divpayoutratio", "[", "t", "]"}], "*", 
              RowBox[{"interimdivpropn", "[", "t", "]"}]}]}], ")"}]}]}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"divpropn2", "\[Equal]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "taxrate"}], ")"}], "divpayoutratio", " ", 
         "interimdivpropn"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"intcash2", "\[Equal]", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "netcash1"}], "+", "intcf2", "-", "intloan2", 
           "-", 
           RowBox[{"ebcit2", " ", "taxrate"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ebcit1", "+", "intcash1", "+", "ebcit2"}], ")"}], 
            "divpropn2"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "/", "netcashintrate"}], ")"}], "-", "1", "+", 
           "taxrate", "+", "divpropn2"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"end", " ", "of", " ", "interest", " ", "calculation"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"interest", "\[Equal]", 
        RowBox[{
        "intloan1", "+", "intloan2", "-", "intcash1", "-", "intcash2"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"depreciation", "\[Equal]", 
        RowBox[{"deprec1", "+", "deprec2"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"pbt", "\[Equal]", 
        RowBox[{
        "sales", "-", "expenses", "-", "depreciation", "-", "interest"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"tax", "\[Equal]", 
        RowBox[{"pbt", " ", "taxrate"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"netprofit", "\[Equal]", 
        RowBox[{"pbt", "-", "tax"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"dividend", "\[Equal]", 
        RowBox[{"netprofit", " ", "divpayoutratio"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"*", " ", "Balance", " ", "Sheet"}], " ", "**)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"netcash", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "netcash", "]"}], "+", "cashflow"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"cash", "\[Equal]", 
        RowBox[{"netcash", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Sign", "[", "netcash", "]"}]}], ")"}], "/", "2"}]}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"debtors", "\[Equal]", 
        RowBox[{"sales", " ", 
         RowBox[{"daysdebtors", "/", "365"}]}]}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"stock", "\[Equal]", 
        RowBox[{"sales", " ", 
         RowBox[{"daysstock", "/", "365"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"fixedassets", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "fixedassets", "]"}], "+", "newassets"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"accumdepreciation", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "accumdepreciation", "]"}], "+", 
         "depreciation"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"netfixedassets", "\[Equal]", 
        RowBox[{"fixedassets", "-", "accumdepreciation"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"totalassets", "\[Equal]", 
        RowBox[{
        "cash", "+", "debtors", "+", "stock", "+", "netfixedassets"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"overdraft", "\[Equal]", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"netcash", "-", "cash"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"creditors", "\[Equal]", 
        RowBox[{"sales", " ", 
         RowBox[{"dayscreditors", "/", "365"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"provdiv", "==", 
        RowBox[{"dividend", 
         RowBox[{"(", 
          RowBox[{"1", "-", "interimdivpropn"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"loan", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "loan", "]"}], "+", "newloan"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"totalliabilities", "\[Equal]", 
        RowBox[{
        "overdraft", "+", "creditors", "+", "provdiv", "+", "loan"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"retainedprofit", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "retainedprofit", "]"}], "+", "netprofit", "-", 
         "dividend"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"capital", "\[Equal]", 
        RowBox[{
         RowBox[{"Prev", "[", "capital", "]"}], "+", "newcapital"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"equity", "\[Equal]", 
        RowBox[{"capital", "+", "retainedprofit"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"balance", "\[Equal]", 
        RowBox[{"totalassets", "-", "totalliabilities", "-", "equity"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"*", " ", "Cash", " ", "Flow"}], " ", "**)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"collections", "\[Equal]", 
        RowBox[{"sales", "-", 
         RowBox[{"(", 
          RowBox[{"debtors", "-", 
           RowBox[{"Prev", "[", "debtors", "]"}]}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"payments", "\[Equal]", 
        RowBox[{"expenses", "-", 
         RowBox[{"(", 
          RowBox[{"creditors", "-", 
           RowBox[{"Prev", "[", "creditors", "]"}]}], ")"}], "+", 
         RowBox[{"(", 
          RowBox[{"stock", "-", 
           RowBox[{"Prev", "[", "stock", "]"}]}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"cashflow", "\[Equal]", 
        RowBox[{
        "collections", "-", "payments", "+", "newloan", "+", "newcapital", 
         "-", "newassets", "-", "interest", "-", "tax", "-", 
         RowBox[{"Prev", "[", "provdiv", "]"}], "-", 
         RowBox[{"(", 
          RowBox[{"dividend", "-", "provdiv"}], ")"}]}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", " ", "Year0"}], " ", "initial", " ", "conditions", " ", 
     "*"}], "**)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqnsinitial", "=", 
     RowBox[{"Hold", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"sales", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "150"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"expenses", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "75"}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"depreciation", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "50"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"interest", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "5"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pbt", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"sales", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"expenses", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"depreciation", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"interest", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"taxrate", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.3"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"tax", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"pbt", "[", 
          RowBox[{"[", "1", "]"}], "]"}], 
         RowBox[{"taxrate", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"netprofit", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"pbt", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"tax", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dividend", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "7"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cash", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "100"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"debtors", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "30"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stock", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "30"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fixedassets", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "500"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"accumdepreciation", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "313"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"netfixedassets", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"fixedassets", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"accumdepreciation", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"totalassets", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"cash", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"debtors", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"stock", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"netfixedassets", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"overdraft", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"creditors", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "20"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"provdiv", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "3.5"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"loan", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "23.5"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"totalliabilities", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"overdraft", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"creditors", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"provdiv", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"loan", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"capital", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "200"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"retainedprofit", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "100"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"equity", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"capital", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"retainedprofit", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"balance", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"totalassets", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"totalliabilities", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"equity", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"collections", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"sales", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"(", 
          RowBox[{"debtors", "[", 
           RowBox[{"[", "1", "]"}], "]"}], 
          RowBox[{"(*", 
           RowBox[{"-", 
            RowBox[{"debtors", "[", 
             RowBox[{"-", "1"}], "]"}]}], "*)"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"payments", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"expenses", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"(", 
          RowBox[{"creditors", "[", 
           RowBox[{"[", "1", "]"}], "]"}], 
          RowBox[{"(*", 
           RowBox[{"-", 
            RowBox[{"creditors", "[", 
             RowBox[{"[", "0", "]"}], "]"}]}], "*)"}], ")"}], "+", 
         RowBox[{"(", 
          RowBox[{"stock", "[", 
           RowBox[{"[", "1", "]"}], "]"}], 
          RowBox[{"(*", 
           RowBox[{"-", 
            RowBox[{"stock", "[", 
             RowBox[{"[", "0", "]"}], "]"}]}], "*)"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cashflow", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"collections", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"payments", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"interest", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"tax", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"dividend", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"newcapital", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"newloan", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"newassets", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"netcash", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"cash", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"overdraft", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"newassets", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{"depreciation", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"newloan", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"newcapital", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"salesgrowthrate", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.1"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"expensesgrowthrate", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.1"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"depreciationrate", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.1"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"netcashintrate", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"loanintrate", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", "2"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"loanintrate", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.1"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"interimdivpropn", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.4"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"interimprofitpropn", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.6"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"interimnewcapitalpropn", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.5"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"interimnewloanpropn", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", "0.5"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"interimnewassetspropn", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0.5"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"daysdebtors", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"debtors", " ", "[", 
          RowBox[{"[", "1", "]"}], "]"}], 
         RowBox[{"365", "/", 
          RowBox[{"sales", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"daysstock", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"stock", " ", "[", 
          RowBox[{"[", "1", "]"}], "]"}], 
         RowBox[{"365", "/", 
          RowBox[{"sales", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dayscreditors", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"creditors", " ", "[", 
          RowBox[{"[", "1", "]"}], "]"}], 
         RowBox[{"365", "/", 
          RowBox[{"sales", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"divpayoutratio", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "==", 
        RowBox[{
         RowBox[{"dividend", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", 
         RowBox[{"netprofit", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"prepare", " ", "the", " ", "vectors"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lhs", "=", 
     RowBox[{"Map", "[", 
      RowBox[{"ToString", ",", 
       RowBox[{"Cases", "[", 
        RowBox[{"eqns", ",", 
         RowBox[{
          RowBox[{"Equal", "[", 
           RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", "a"}]}], "]"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Scan", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"assignElementsFull", "[", 
       RowBox[{"#", ",", "\"\<\[Gamma]\>\"", ",", "n"}], "]"}], "&"}], ",", 
     "lhs"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"solve", " ", "the", " ", "initial", " ", "conditions"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initial2", "=", 
     RowBox[{"Apply", "[", 
      RowBox[{"List", ",", 
       RowBox[{"Map", "[", 
        RowBox[{"ReleaseHold", ",", "eqnsinitial"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialr", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Solve", "[", "initial2", "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"solve", " ", "the", " ", "main", " ", "model"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"prepare", " ", "the", " ", "main", " ", "model"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", "=", 
     RowBox[{"Apply", "[", 
      RowBox[{"List", ",", 
       RowBox[{"Map", "[", 
        RowBox[{"ReleaseHold", ",", "eqns"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lhs2", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Map", "[", 
       RowBox[{"Rest", ",", 
        RowBox[{"Cases", "[", 
         RowBox[{"eqns2", ",", 
          RowBox[{
           RowBox[{"Equal", "[", 
            RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", "a"}]}], "]"}]}], 
       "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rhs2", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Map", "[", 
       RowBox[{"Rest", ",", 
        RowBox[{"Cases", "[", 
         RowBox[{"eqns2", ",", 
          RowBox[{
           RowBox[{"Equal", "[", 
            RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", "b"}]}], "]"}]}], 
       "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solutionr", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"lhs2", "\[Equal]", 
         RowBox[{"(", 
          RowBox[{"rhs2", "/.", "initialr"}], ")"}]}], "}"}], ",", "lhs2"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"resultsr", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"initialr", ",", "solutionr"}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Time: \>\"", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"AbsoluteTime", "[", "]"}], "-", "timestart"}], ")"}], "/", 
       "3600"}], ",", "\"\<; Memory Mb: \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"MaxMemoryUsed", "[", "]"}], "/", 
        RowBox[{"10", "^", "6"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"present", " ", "output"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BlankLine", "=", 
     RowBox[{"{", "\"\<\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Join", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", 
             RowBox[{"-", "1"}]}], ",", "\"\<Profit & Loss\>\"", ",", 
            RowBox[{"\"\<Year\>\"", "<>", 
             RowBox[{"ToString", "[", "i", "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "1"}], ",", "periods"}], "}"}]}], "]"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"#", "\[Equal]", "\"\<BlankLine\>\""}], ",", 
                "\"\<\>\"", ",", "#"}], "]"}], "}"}], ",", 
             RowBox[{"ToExpression", "[", "#", "]"}]}], "]"}], "&"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<sales\>\"", ",", "\"\<expenses\>\"", ",", 
            "\"\<depreciation\>\"", ",", "\"\<interest\>\"", ",", 
            "\"\<pbt\>\"", ",", "\"\<tax\>\"", ",", "\"\<netprofit\>\"", ",", 
            "\"\<dividend\>\"", ",", "\"\<BlankLine\>\""}], "}"}]}], "]"}], "/.",
         "resultsr"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", 
             RowBox[{"-", "1"}]}], ",", "\"\<Balance Sheet\>\"", ",", 
            RowBox[{"\"\<Year\>\"", "<>", 
             RowBox[{"ToString", "[", "i", "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "1"}], ",", "periods"}], "}"}]}], "]"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"#", "\[Equal]", "\"\<BlankLine\>\""}], ",", 
                "\"\<\>\"", ",", "#"}], "]"}], "}"}], ",", 
             RowBox[{"ToExpression", "[", "#", "]"}]}], "]"}], "&"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<cash\>\"", ",", "\"\<debtors\>\"", ",", "\"\<stock\>\"", ",", 
            "\"\<fixedassets\>\"", ",", "\"\<accumdepreciation\>\"", ",", 
            "\"\<netfixedassets\>\"", ",", "\"\<totalassets\>\"", ",", 
            "\"\<BlankLine\>\"", ",", "\[IndentingNewLine]", 
            "\"\<overdraft\>\"", ",", "\"\<creditors\>\"", ",", 
            "\"\<provdiv\>\"", ",", "\"\<loan\>\"", ",", 
            "\"\<totalliabilities\>\"", ",", "\"\<BlankLine\>\"", ",", 
            "\"\<capital\>\"", ",", "\"\<retainedprofit\>\"", ",", 
            "\"\<equity\>\"", ",", "\"\<BlankLine\>\"", ",", 
            "\"\<balance\>\"", ",", "\"\<BlankLine\>\""}], "}"}]}], "]"}], "/.",
         "resultsr"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", 
             RowBox[{"-", "1"}]}], ",", "\"\<CashFlow\>\"", ",", 
            RowBox[{"\"\<Year\>\"", "<>", 
             RowBox[{"ToString", "[", "i", "]"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "1"}], ",", "periods"}], "}"}]}], "]"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"#", "\[Equal]", "\"\<BlankLine\>\""}], ",", 
                "\"\<\>\"", ",", "#"}], "]"}], "}"}], ",", 
             RowBox[{"ToExpression", "[", "#", "]"}]}], "]"}], "&"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<collections\>\"", ",", "\"\<payments\>\"", ",", 
            "\"\<interest\>\"", ",", "\"\<tax\>\"", ",", "\"\<dividend\>\"", 
            ",", "\"\<newcapital\>\"", ",", "\"\<newloan\>\"", ",", 
            "\"\<newassets\>\"", ",", "\"\<cashflow\>\"", ",", 
            "\"\<cash\>\""}], "\[IndentingNewLine]", "}"}]}], "]"}], "/.", 
        "resultsr"}]}], "]"}], ",", " ", 
     RowBox[{"Alignment", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", "Left", "}"}], "}"}]}], ",", 
     RowBox[{"Dividers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{"False", ",", "True", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"False", ",", 
             RowBox[{"{", "9", "}"}]}], "]"}], ",", "True", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"False", ",", 
             RowBox[{"{", "20", "}"}]}], "]"}], ",", "True"}], "}"}], "]"}]}],
        "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.484099170826287*^9, 3.484099228531367*^9}, {
   3.484099269886609*^9, 3.484099289162624*^9}, {3.484099325358771*^9, 
   3.484100203129839*^9}, {3.484100240619221*^9, 3.48410046979984*^9}, {
   3.484100500815745*^9, 3.484100584137966*^9}, {3.484100621982526*^9, 
   3.484100624452112*^9}, {3.484100660754379*^9, 3.484100684730009*^9}, {
   3.484100715062132*^9, 3.484100725017756*^9}, {3.484100842139996*^9, 
   3.484100997996474*^9}, {3.484101030266056*^9, 3.484101303463465*^9}, {
   3.484101336696508*^9, 3.484101370692303*^9}, {3.484101447372478*^9, 
   3.484101472897915*^9}, {3.484101554038667*^9, 3.484101555811046*^9}, {
   3.484101610708691*^9, 3.48410161955189*^9}, {3.484101672167019*^9, 
   3.484101747383766*^9}, {3.484101778046779*^9, 3.484101858721896*^9}, {
   3.484101917997473*^9, 3.484102115709622*^9}, {3.484102146330671*^9, 
   3.484102202364195*^9}, {3.484102335685094*^9, 3.4841024266271*^9}, {
   3.484102460297351*^9, 3.484102621432811*^9}, {3.484102665618697*^9, 
   3.484102683603112*^9}, {3.484102735488161*^9, 3.484102776488298*^9}, {
   3.484102874878945*^9, 3.484102904484274*^9}, {3.484102947469211*^9, 
   3.484102949856395*^9}, {3.484102990844136*^9, 3.484103011986676*^9}, {
   3.484103047206252*^9, 3.484103144642805*^9}, {3.484103190782797*^9, 
   3.484103210348529*^9}, {3.484103311775594*^9, 3.484103371903595*^9}, {
   3.484103404527037*^9, 3.484103511871324*^9}, {3.484103608880084*^9, 
   3.484103613730111*^9}, {3.484103679740215*^9, 3.48410368677848*^9}, {
   3.484103781671772*^9, 3.48410387347734*^9}, {3.484104020241087*^9, 
   3.484104024464926*^9}, {3.484104118551413*^9, 3.484104155239702*^9}, {
   3.484104194015794*^9, 3.484104213121614*^9}, {3.484104274784276*^9, 
   3.484104277894871*^9}, {3.484104388981597*^9, 3.484104396680494*^9}, {
   3.484104462645227*^9, 3.48410446785495*^9}, {3.484104507582281*^9, 
   3.484104561833675*^9}, {3.484104616320567*^9, 3.484104619871262*^9}, {
   3.484104705227612*^9, 3.484104709413844*^9}, {3.484104953101699*^9, 
   3.484104956334768*^9}, {3.484104999600648*^9, 3.484105002473008*^9}, {
   3.484105199333197*^9, 3.484105213332591*^9}, {3.484105251724154*^9, 
   3.484105257582394*^9}, {3.484105290743897*^9, 3.484105292583898*^9}, {
   3.484105329796701*^9, 3.484105355568484*^9}, {3.484105405969667*^9, 
   3.484105432671117*^9}, {3.48410561325677*^9, 3.484105618288971*^9}, {
   3.484105649835516*^9, 3.484105712761689*^9}, {3.484105836663172*^9, 
   3.484105852898584*^9}, {3.484105915891171*^9, 3.484105923818388*^9}, {
   3.484105982185752*^9, 3.484105999338168*^9}, {3.484106059397096*^9, 
   3.484106094074478*^9}, {3.484106143739452*^9, 3.484106192194559*^9}, {
   3.484106244216179*^9, 3.484106280490483*^9}, {3.484106449592321*^9, 
   3.484106497851997*^9}, {3.484106541379252*^9, 3.484106547525162*^9}, {
   3.484106640318938*^9, 3.484106684089643*^9}, {3.484106745855479*^9, 
   3.48410679933875*^9}, {3.484106860364276*^9, 3.484107016295083*^9}, {
   3.484107191793768*^9, 3.484107220905611*^9}, {3.484107287167406*^9, 
   3.484107305138702*^9}, {3.484107372814625*^9, 3.484107408854971*^9}, {
   3.48410756571369*^9, 3.484107612891683*^9}, {3.484107680027778*^9, 
   3.484107756927436*^9}, {3.484107852229283*^9, 3.484107853998738*^9}, {
   3.484107992697407*^9, 3.484108001973179*^9}, {3.48410804769657*^9, 
   3.484108057287487*^9}, {3.484108088204245*^9, 3.484108099590294*^9}, {
   3.484108150303418*^9, 3.484108214299003*^9}, {3.484108286346355*^9, 
   3.484108430725912*^9}, {3.484108609665679*^9, 3.484108628760279*^9}, {
   3.484108660531886*^9, 3.484108661110121*^9}, {3.484108899525182*^9, 
   3.484109077172947*^9}, {3.484109161793401*^9, 3.484109163432876*^9}, {
   3.484110376966348*^9, 3.484110410989986*^9}, {3.484110502985582*^9, 
   3.484110546847364*^9}, {3.48411090830379*^9, 3.484110915055302*^9}, {
   3.484111024349753*^9, 3.484111028089702*^9}, {3.484111087023723*^9, 
   3.484111094491631*^9}, {3.484111261002435*^9, 3.484111339921321*^9}, {
   3.484111435633294*^9, 3.484111450473896*^9}, {3.484111537855733*^9, 
   3.484111590112417*^9}, {3.484111640699494*^9, 3.484111666146731*^9}, {
   3.484111780985738*^9, 3.484112103137231*^9}, {3.484112145975432*^9, 
   3.484112354367166*^9}, {3.484112594751093*^9, 3.484112616093197*^9}, {
   3.484113246130498*^9, 3.484113289334735*^9}, {3.484113323163263*^9, 
   3.484113357306393*^9}, {3.484113388645499*^9, 3.484113448238572*^9}, {
   3.484113510719474*^9, 3.484113721637905*^9}, {3.484113878957868*^9, 
   3.484113883767063*^9}, {3.484113934508233*^9, 3.484113935326065*^9}, 
   3.484114071847041*^9, {3.484114507700533*^9, 3.484114509176673*^9}, {
   3.484114548021458*^9, 3.484114586684582*^9}, {3.484114633105404*^9, 
   3.484114643050082*^9}, {3.48411469105169*^9, 3.484114699093773*^9}, {
   3.484114946089457*^9, 3.484115010845477*^9}, {3.484115060728218*^9, 
   3.484115089702062*^9}, {3.48411513836749*^9, 3.484115216155535*^9}, {
   3.48411526977345*^9, 3.484115291090887*^9}, {3.484115343141364*^9, 
   3.484115426166397*^9}, {3.484115531400265*^9, 3.484115560306355*^9}, {
   3.484115768312525*^9, 3.484115771717795*^9}, {3.484115811466583*^9, 
   3.484115818667152*^9}, {3.484116034938513*^9, 3.484116041928504*^9}, {
   3.48411621652473*^9, 3.48411621937658*^9}, {3.484116343928548*^9, 
   3.48411634847466*^9}, {3.484116459854806*^9, 3.484116636310751*^9}, {
   3.484116693580767*^9, 3.484116697364131*^9}, {3.484116749688241*^9, 
   3.484116799333674*^9}, {3.484116847356243*^9, 3.484117011949796*^9}, 
   3.484117107144255*^9, {3.484117177956527*^9, 3.484117194558317*^9}, {
   3.484117243892871*^9, 3.484117324099203*^9}, {3.484117515785188*^9, 
   3.484117519428386*^9}, {3.484117557925638*^9, 3.484117560326657*^9}, {
   3.484117614826781*^9, 3.484117615706031*^9}, {3.484117656952892*^9, 
   3.484117662581397*^9}, {3.484117693146211*^9, 3.484117704166686*^9}, {
   3.48411780871694*^9, 3.484118483439604*^9}, {3.484118513515616*^9, 
   3.484118584496701*^9}, {3.484118642039102*^9, 3.484118675683288*^9}, {
   3.484118713228877*^9, 3.4841191265774*^9}, {3.4841191651449*^9, 
   3.484119267198845*^9}, {3.484119301632591*^9, 3.484119391161113*^9}, {
   3.484119428372939*^9, 3.484119550577627*^9}, {3.484119599040426*^9, 
   3.484119600965738*^9}, {3.484119670764931*^9, 3.484119764790077*^9}, {
   3.48411981582012*^9, 3.48411993910548*^9}, {3.48411998286815*^9, 
   3.484120380832194*^9}, {3.484120413499314*^9, 3.484120432021915*^9}, {
   3.484120462358662*^9, 3.484120509450512*^9}, {3.484120569819925*^9, 
   3.484120597370755*^9}, {3.484120635537194*^9, 3.484120695495633*^9}, {
   3.484120772128237*^9, 3.484120788209841*^9}, {3.484120826416853*^9, 
   3.484120827024024*^9}, {3.484120938287842*^9, 3.484120966738959*^9}, {
   3.484122169990674*^9, 3.484122174808614*^9}, {3.48412220772429*^9, 
   3.484122284930111*^9}, {3.484122349778933*^9, 3.484122381453655*^9}, {
   3.48412244431622*^9, 3.484122470840218*^9}, {3.484122524716559*^9, 
   3.484122542806135*^9}, {3.484122673750826*^9, 3.484122731855629*^9}, {
   3.484122863414253*^9, 3.484122944200525*^9}, {3.484123028721345*^9, 
   3.484123029027765*^9}, {3.4841231480139*^9, 3.484123271173991*^9}, {
   3.484123354316606*^9, 3.48412335638605*^9}, {3.484123433780354*^9, 
   3.484123434916476*^9}, {3.484123489305772*^9, 3.484123490316999*^9}, {
   3.484123554631079*^9, 3.484123557812086*^9}, {3.484123887900448*^9, 
   3.484123891123516*^9}, {3.484124060223806*^9, 3.484124140840567*^9}, {
   3.484124195282464*^9, 3.484124211438836*^9}, {3.484124552933138*^9, 
   3.484124702168622*^9}, {3.484124791850306*^9, 3.484124818345148*^9}, {
   3.484124937121571*^9, 3.484124963711879*^9}, {3.484125037928243*^9, 
   3.484125042603085*^9}, {3.484125106440351*^9, 3.484125106943653*^9}, {
   3.484125165726853*^9, 3.484125202548325*^9}, {3.484125233645569*^9, 
   3.484125314883648*^9}, {3.48412536063675*^9, 3.484125538919608*^9}, {
   3.48412746683709*^9, 3.484127543648576*^9}, {3.484127623343919*^9, 
   3.484127625205582*^9}, {3.484127661504988*^9, 3.484127663453369*^9}, {
   3.484127729557949*^9, 3.484127738330652*^9}, {3.484127789892481*^9, 
   3.484127794444044*^9}, {3.484127855185647*^9, 3.484127866375796*^9}, {
   3.484127907458119*^9, 3.484127908085373*^9}, {3.484128206139617*^9, 
   3.484128274271006*^9}, {3.484128326835858*^9, 3.484128327239029*^9}, {
   3.484128500893518*^9, 3.484128501289123*^9}, {3.48429439384594*^9, 
   3.484294730331062*^9}, {3.484294760891479*^9, 3.484295218743961*^9}, {
   3.484295264752538*^9, 3.484295518499467*^9}, {3.484295556438311*^9, 
   3.484295569181361*^9}, {3.484295631257699*^9, 3.484295777183023*^9}, {
   3.484295891374496*^9, 3.484295912277657*^9}, {3.484296016325641*^9, 
   3.484296024710168*^9}, {3.484296075646555*^9, 3.484296111172222*^9}, {
   3.484296151144264*^9, 3.484296187408811*^9}, {3.48429622292956*^9, 
   3.484296301771707*^9}, {3.484296331789518*^9, 3.484296425614025*^9}, {
   3.484296572729273*^9, 3.484297048363847*^9}, {3.484297095993363*^9, 
   3.484297338999142*^9}, {3.484297425424148*^9, 3.484297448456529*^9}, {
   3.484297493518582*^9, 3.484297533896152*^9}, {3.484297583680455*^9, 
   3.484297743902883*^9}, {3.484297811945525*^9, 3.484297901404805*^9}, {
   3.484297933643726*^9, 3.484298033530815*^9}, {3.484298083106502*^9, 
   3.484298169401173*^9}, {3.484298217764413*^9, 3.484298411012745*^9}, {
   3.484298443885422*^9, 3.484298610501648*^9}, {3.484298664746916*^9, 
   3.484298665567681*^9}, {3.484298714436779*^9, 3.484298752085066*^9}, {
   3.484298844550319*^9, 3.484298846723489*^9}, {3.4842988874849*^9, 
   3.484298912363601*^9}, {3.484298969088649*^9, 3.484298970177766*^9}, {
   3.484299336070921*^9, 3.484299339848296*^9}, {3.484299372436594*^9, 
   3.484299489293094*^9}, {3.484299539975885*^9, 3.484299641384149*^9}, 
   3.484299777996512*^9, {3.484300086763958*^9, 3.484300155951816*^9}, {
   3.48430019146722*^9, 3.484300227549169*^9}, {3.484300339606017*^9, 
   3.4843003399947*^9}, {3.484300398305841*^9, 3.484300399252701*^9}, {
   3.484701751418592*^9, 3.484701752678164*^9}, {3.484701849406016*^9, 
   3.484701862284686*^9}, {3.484701898839289*^9, 3.484701948950614*^9}, {
   3.484701994840388*^9, 3.484701995510053*^9}, {3.484702030404835*^9, 
   3.484702036209308*^9}, 3.484702118734301*^9, 3.484702161054105*^9, {
   3.484702452453986*^9, 3.484702480004353*^9}, {3.484702516912199*^9, 
   3.484702525180563*^9}, {3.484702600180696*^9, 3.48470262326814*^9}, {
   3.48470282626781*^9, 3.484702851643751*^9}, {3.4847029182146*^9, 
   3.484702918910552*^9}, {3.484703074844676*^9, 3.484703127122596*^9}, {
   3.484703214715145*^9, 3.484703224082406*^9}, {3.484703677860826*^9, 
   3.484703695479156*^9}, {3.484707726245441*^9, 3.484707729352048*^9}, {
   3.484710599265232*^9, 3.484710661072403*^9}, {3.484710756149922*^9, 
   3.48471075987569*^9}, 3.484710809960985*^9, {3.484710872206417*^9, 
   3.484711016528193*^9}, 3.484711078657726*^9, 3.484711122568265*^9, {
   3.48471119014059*^9, 3.484711207989863*^9}, {3.484711408648118*^9, 
   3.484711443188785*^9}, {3.484711538925509*^9, 3.484711585888366*^9}, {
   3.484711677394281*^9, 3.484711702928742*^9}, {3.484711742458909*^9, 
   3.484711777454005*^9}, {3.484711829905711*^9, 3.484711855139916*^9}, {
   3.4847119049347*^9, 3.484711937327675*^9}, 3.484712014740506*^9, {
   3.484712112000278*^9, 3.48471211237646*^9}, 3.484712159291219*^9, {
   3.484712215320547*^9, 3.48471222471674*^9}, {3.484712293302784*^9, 
   3.484712298080667*^9}, {3.484712402206017*^9, 3.484712428278712*^9}, {
   3.484782688888247*^9, 3.484782709127562*^9}, {3.484782745976391*^9, 
   3.484782756140758*^9}, {3.484782882900329*^9, 3.484782886252632*^9}, {
   3.484782966763866*^9, 3.484782967467684*^9}, {3.484782998006362*^9, 
   3.484783215244214*^9}, {3.484783247504523*^9, 3.484783452149468*^9}, {
   3.484783492429875*^9, 3.4847836305575*^9}, {3.484783666277218*^9, 
   3.484783784918963*^9}, {3.484783856987864*^9, 3.484783874745079*^9}, {
   3.484783918325741*^9, 3.484783932735658*^9}, {3.484783966705033*^9, 
   3.484783969522037*^9}, {3.484784057793643*^9, 3.484784062529907*^9}, {
   3.484784139460618*^9, 3.484784190027354*^9}, {3.484784256325781*^9, 
   3.484784461020284*^9}, {3.484784519236564*^9, 3.484784529701564*^9}, {
   3.484784571584962*^9, 3.484784572741104*^9}, {3.484784660888984*^9, 
   3.484784661674914*^9}, {3.4847847714539*^9, 3.484784777086307*^9}, {
   3.484784807142428*^9, 3.484784810991411*^9}, {3.484784881358852*^9, 
   3.48478489286527*^9}, {3.484785123653307*^9, 3.484785153828632*^9}, {
   3.484785280239995*^9, 3.484785420965097*^9}, {3.484785498663399*^9, 
   3.484785512666108*^9}, {3.484785738445796*^9, 3.484785761709362*^9}, {
   3.484785799184891*^9, 3.484786202537902*^9}, {3.48478627403744*^9, 
   3.484786372257936*^9}, {3.48478642988504*^9, 3.484786505846327*^9}, {
   3.484786631140591*^9, 3.484786678890867*^9}, {3.484786745502582*^9, 
   3.484786764937446*^9}, {3.484786820064407*^9, 3.484786880754581*^9}, {
   3.484786913008105*^9, 3.484786920750711*^9}, {3.484786976443032*^9, 
   3.484787003121221*^9}, {3.484787045856356*^9, 3.484787077028543*^9}, {
   3.484787137242947*^9, 3.484787251689307*^9}, {3.484787432294771*^9, 
   3.484787435305199*^9}, {3.484787502913619*^9, 3.484787510199216*^9}, {
   3.484787540484758*^9, 3.484787599982795*^9}, {3.484787809848129*^9, 
   3.484787816523004*^9}, {3.484787853027029*^9, 3.484787855940837*^9}, 
   3.484788120458449*^9, {3.48478826180843*^9, 3.484788290995457*^9}, {
   3.484788508065235*^9, 3.484788518517549*^9}, {3.484788654928854*^9, 
   3.484788666324937*^9}, {3.484788706931609*^9, 3.484788786552805*^9}, {
   3.484788939860269*^9, 3.484788940906809*^9}, {3.484789311672447*^9, 
   3.484789372736687*^9}, 3.484789407670066*^9, {3.48478972784741*^9, 
   3.484789756735769*^9}, 3.48479013978952*^9, {3.484790451945212*^9, 
   3.484790458203993*^9}, {3.484792318024358*^9, 3.484792370700279*^9}, {
   3.484792402223153*^9, 3.484792407059851*^9}, {3.484792788061348*^9, 
   3.484792849283972*^9}, {3.484793586191652*^9, 3.484793586640417*^9}, 
   3.48479478059533*^9, {3.484795573425017*^9, 3.484795575580334*^9}, {
   3.484796367874708*^9, 3.484796374794206*^9}, {3.484797409004284*^9, 
   3.484797415615865*^9}, {3.484801181006081*^9, 3.48480122963249*^9}, {
   3.484801417449099*^9, 3.484801434268784*^9}, {3.484801708550054*^9, 
   3.484801712057238*^9}, {3.484802741564881*^9, 3.484802757985107*^9}, {
   3.484803032796268*^9, 3.484803036982809*^9}, {3.484803684058267*^9, 
   3.484803688585288*^9}, {3.484805262614194*^9, 3.484805488098472*^9}, {
   3.484805536861505*^9, 3.484805992066692*^9}, {3.484806029154372*^9, 
   3.484806304611079*^9}, {3.484806340432338*^9, 3.484806404967356*^9}, {
   3.484806450690222*^9, 3.484806452470877*^9}, {3.484806532120326*^9, 
   3.484806552447329*^9}, {3.48480658860675*^9, 3.484806615349728*^9}, {
   3.484806691619852*^9, 3.484806734768577*^9}, 3.484806777518736*^9, {
   3.484806826137277*^9, 3.484806918040921*^9}, 3.484807450180847*^9, 
   3.484807484410882*^9, {3.484807535907955*^9, 3.484807544010473*^9}, {
   3.484807586518751*^9, 3.484807796573723*^9}, 3.484808649770863*^9, {
   3.484809000563494*^9, 3.48480913374221*^9}, {3.484809229217395*^9, 
   3.484809392081452*^9}, {3.484809466236236*^9, 3.48480950436086*^9}, {
   3.48480958468015*^9, 3.484810277251582*^9}, {3.484810376261514*^9, 
   3.484810381851596*^9}, {3.484810603155312*^9, 3.484810645630599*^9}, {
   3.48481070686087*^9, 3.484810785421299*^9}, {3.484811011495417*^9, 
   3.484811085586818*^9}, {3.484811123462306*^9, 3.484811130365463*^9}, {
   3.484811167825824*^9, 3.484811401153867*^9}, {3.484811571449099*^9, 
   3.484811587207418*^9}, {3.48481202966483*^9, 3.484812086941271*^9}, {
   3.484812221502307*^9, 3.484812268472899*^9}, 3.484812377876968*^9, {
   3.484813117870612*^9, 3.484813272663478*^9}, {3.484813335426999*^9, 
   3.484813355925409*^9}, 3.484813546479524*^9, {3.484813579193508*^9, 
   3.484813684751813*^9}, 3.484813718110115*^9, {3.484813797990812*^9, 
   3.484813964395945*^9}, {3.484814001903144*^9, 3.484814098518087*^9}, {
   3.48481412952022*^9, 3.48481415501671*^9}, {3.48481418776885*^9, 
   3.484814196885538*^9}, 3.484814239463685*^9, {3.484814273089408*^9, 
   3.484814370257467*^9}, 3.484814406459161*^9, {3.484814692284885*^9, 
   3.484814827253406*^9}, {3.484814867910437*^9, 3.484814934959172*^9}, {
   3.484815431857708*^9, 3.484815902491745*^9}, {3.484815933890942*^9, 
   3.484815986676113*^9}, {3.484816045740077*^9, 3.484816090107851*^9}, {
   3.4848161211292*^9, 3.484816245374075*^9}, {3.484816282990277*^9, 
   3.484816426117589*^9}, {3.484817477984914*^9, 3.484817543885159*^9}, {
   3.484888642071953*^9, 3.484888645080167*^9}, {3.484888678467353*^9, 
   3.484888738754691*^9}, {3.484888781901501*^9, 3.48488887378994*^9}, {
   3.484888938418729*^9, 3.48488898309846*^9}, {3.484889021989254*^9, 
   3.484889311657391*^9}, {3.484889360828159*^9, 3.484890024278052*^9}, {
   3.484890095928173*^9, 3.484890334204175*^9}, {3.484891176682741*^9, 
   3.484891554968063*^9}, 3.48489163844047*^9, {3.484892838734932*^9, 
   3.484892853597739*^9}, 3.484893757723647*^9, {3.48489383062534*^9, 
   3.48489383146823*^9}, {3.484893950999469*^9, 3.484893955490449*^9}, {
   3.484895811884676*^9, 3.48489581516259*^9}, {3.484897280447614*^9, 
   3.484897283833199*^9}, {3.484897606676688*^9, 3.484897609926942*^9}, {
   3.484898159627828*^9, 3.484898167373924*^9}, {3.484900089115389*^9, 
   3.484900120250954*^9}, {3.484900187013435*^9, 3.484900826918674*^9}, {
   3.484900863175889*^9, 3.484900992959056*^9}, {3.484901025082541*^9, 
   3.484901105717753*^9}, {3.484901341057052*^9, 3.484901347652736*^9}, {
   3.484901414936474*^9, 3.484901471812658*^9}, {3.484901622549283*^9, 
   3.484901639380474*^9}, {3.484902151489297*^9, 3.48490215994661*^9}, {
   3.484902317796141*^9, 3.48490244878946*^9}, {3.484902494139555*^9, 
   3.484902534617479*^9}, {3.484902577650205*^9, 3.484902581085172*^9}, {
   3.484902675150616*^9, 3.484902717408645*^9}, {3.484902757133833*^9, 
   3.484902847506376*^9}, 3.484963718593648*^9, {3.484963751871081*^9, 
   3.484963790799193*^9}, {3.484963827596126*^9, 3.484963869969672*^9}, {
   3.484963943958452*^9, 3.484964032921597*^9}, {3.484964064466373*^9, 
   3.484964216609918*^9}, {3.484964252111583*^9, 3.484964300213803*^9}, {
   3.484964350427645*^9, 3.484964461183133*^9}, {3.484964513141129*^9, 
   3.484964538873423*^9}, {3.484964576221838*^9, 3.484964587383734*^9}, {
   3.484964622050794*^9, 3.48496467362935*^9}, {3.484964704051589*^9, 
   3.484964706445962*^9}, {3.484964771720495*^9, 3.484964772174019*^9}, {
   3.485054592847623*^9, 3.485054637579976*^9}, {3.485054679107996*^9, 
   3.485054811719845*^9}, {3.485054866908805*^9, 3.485054967838713*^9}, {
   3.485055013775528*^9, 3.485055026054296*^9}, {3.485055066714714*^9, 
   3.485055101087416*^9}, {3.48505527330116*^9, 3.485055286121873*^9}, {
   3.48505534026835*^9, 3.485055403491071*^9}, {3.485055464546064*^9, 
   3.485055489992064*^9}, {3.485056579788358*^9, 3.485056580163693*^9}, {
   3.485056738487279*^9, 3.485056765140123*^9}, {3.485056810794261*^9, 
   3.485056866420466*^9}, {3.485056923839015*^9, 3.485057068771459*^9}, {
   3.485057442609769*^9, 3.4850574645656*^9}, {3.485057508146962*^9, 
   3.485057594645272*^9}, {3.485057648955883*^9, 3.485057650564624*^9}, {
   3.485057722831068*^9, 3.485057754734591*^9}, {3.485057912112563*^9, 
   3.485057925789342*^9}, {3.485058032135706*^9, 3.485058039138258*^9}, 
   3.485058095106283*^9, {3.4850584035206*^9, 3.485058411242563*^9}, {
   3.485058446063127*^9, 3.48505852152937*^9}, {3.485058572069346*^9, 
   3.485058593701861*^9}, {3.485156996659965*^9, 3.485157026584789*^9}, {
   3.48515708720506*^9, 3.485157235797019*^9}, 3.485158350314796*^9, {
   3.485158394676052*^9, 3.485158535855339*^9}, {3.485158609522134*^9, 
   3.485158610197574*^9}, {3.485158804447589*^9, 3.48515880517075*^9}, {
   3.485158896863274*^9, 3.485158929120239*^9}, {3.485159003418371*^9, 
   3.485159003999022*^9}, {3.48515905260671*^9, 3.485159061305618*^9}, {
   3.485159115978517*^9, 3.485159123773892*^9}, {3.485159166544336*^9, 
   3.485159233067873*^9}, {3.485159802423185*^9, 3.48515984017514*^9}, {
   3.48516025821333*^9, 3.485160262554234*^9}, {3.485160295223592*^9, 
   3.485160295883099*^9}, {3.485160331067442*^9, 3.485160340638838*^9}, {
   3.485160372397181*^9, 3.485160403957716*^9}, {3.485160466008491*^9, 
   3.485160484093348*^9}, {3.485160517717965*^9, 3.485160552594216*^9}, {
   3.485160603723274*^9, 3.485160605305659*^9}, {3.485160661970419*^9, 
   3.485160662831795*^9}, {3.485160916738439*^9, 3.485160975514369*^9}, {
   3.485161025952236*^9, 3.48516117644814*^9}, {3.485161212252639*^9, 
   3.485161228892637*^9}, {3.48516126336893*^9, 3.485161419668525*^9}, {
   3.485161489215668*^9, 3.485161580095112*^9}, {3.485161646141181*^9, 
   3.485161737917227*^9}, {3.485161768565188*^9, 3.485161804698093*^9}, {
   3.485162070043289*^9, 3.485162152786016*^9}, {3.485162572265352*^9, 
   3.485162664675204*^9}, {3.485162739355033*^9, 3.485162739950402*^9}, {
   3.485162792632797*^9, 3.485162796312319*^9}, {3.485206853788134*^9, 
   3.485206862676487*^9}, {3.485206894413095*^9, 3.485206897501583*^9}, {
   3.485585681145749*^9, 3.485585740711365*^9}, {3.485585918143987*^9, 
   3.48558592329347*^9}, {3.485667576962941*^9, 3.485667601198155*^9}, {
   3.4856733279149933`*^9, 3.485673329774768*^9}, {3.485674171853953*^9, 
   3.485674190957801*^9}, {3.489369844521195*^9, 3.48936988560559*^9}, {
   3.489369930770941*^9, 3.489369937203126*^9}, {3.4893707228313017`*^9, 
   3.489370723326027*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "::", "\<\"rmnsm\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"There are no symbols \
matching \\\\\\\\\\\\\\\"\\\\\\\"\\\", \
\\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\!\\(\\\"Global`*\\\"\\), \\\"MT\\\
\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\\\\\\\\".\\\\\\\"\\\", \
\\\"MT\\\"]\\) \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Remove/rmnsm\\\", ButtonNote -> \
\\\"Remove::rmnsm\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.48937073761069*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Time: \"\>", "\[InvisibleSpace]", 
   "0.01880160861111111111111111111111111111`8.28204250209303", 
   "\[InvisibleSpace]", "\<\"; Memory Mb: \"\>", "\[InvisibleSpace]", 
   "27.094152`"}],
  SequenceForm[
  "Time: ", 0.01880160861111111111111111111111111111`8.28204250209303, 
   "; Memory Mb: ", 27.094152],
  Editable->False]], "Print",
 CellChangeTimes->{3.489370805295889*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Profit & Loss\"\>", "\<\"Year0\"\>", "\<\"Year1\"\>", \
"\<\"Year2\"\>", "\<\"Year3\"\>"},
    {"\<\"sales\"\>", "150.`", "165.`", "181.5`", "199.65`"},
    {"\<\"expenses\"\>", "75.`", "82.5`", "90.75`", "99.825`"},
    {"\<\"depreciation\"\>", "50.`", "21.2`", "22.64`", "22.568`"},
    {"\<\"interest\"\>", "5.`", 
     RowBox[{"-", "2.95636215805722`"}], 
     RowBox[{"-", "3.691776135538819`"}], 
     RowBox[{"-", "4.989478112395531`"}]},
    {"\<\"pbt\"\>", "20.`", "64.25636215805721`", "71.80177613553882`", 
     "82.24647811239554`"},
    {"\<\"tax\"\>", "6.`", "19.276908647417166`", "21.540532840661644`", 
     "24.67394343371866`"},
    {"\<\"netprofit\"\>", "14.`", "44.979453510640056`", 
     "50.261243294877175`", "57.572534678676874`"},
    {"\<\"dividend\"\>", "7.`", "22.489726755320028`", "25.130621647438588`", 
     "28.786267339338437`"},
    {"\<\"\"\>", "\<\"\"\>", "", "", ""},
    {"\<\"Balance Sheet\"\>", "\<\"Year0\"\>", "\<\"Year1\"\>", \
"\<\"Year2\"\>", "\<\"Year3\"\>"},
    {"\<\"cash\"\>", "100.`", "99.68356280851205`", "123.43872139122176`", 
     "149.5063761457001`"},
    {"\<\"debtors\"\>", "30.`", "33.`", "36.3`", "39.93`"},
    {"\<\"stock\"\>", "30.`", "33.`", "36.3`", "39.93`"},
    {"\<\"fixedassets\"\>", "500.`", "550.`", "571.2`", "593.84`"},
    {"\<\"accumdepreciation\"\>", "313.`", "334.2`", "356.84`", "379.408`"},
    {"\<\"netfixedassets\"\>", "187.`", "215.8`", "214.36`", "214.432`"},
    {"\<\"totalassets\"\>", "347.`", "381.48356280851203`", 
     "410.3987213912218`", "443.7983761457001`"},
    {"\<\"\"\>", "\<\"\"\>", "", "", ""},
    {"\<\"overdraft\"\>", "0.`", "0.`", "0.`", "0.`"},
    {"\<\"creditors\"\>", "20.`", "22.`", "24.2`", "26.62`"},
    {"\<\"provdiv\"\>", "3.5`", "13.493836053192016`", "15.078372988463151`", 
     "17.27176040360306`"},
    {"\<\"loan\"\>", "23.5`", "23.5`", "23.5`", "23.5`"},
    {"\<\"totalliabilities\"\>", "47.`", "58.99383605319202`", 
     "62.778372988463154`", "67.39176040360306`"},
    {"\<\"\"\>", "\<\"\"\>", "", "", ""},
    {"\<\"capital\"\>", "200.`", "200.`", "200.`", "200.`"},
    {"\<\"retainedprofit\"\>", "100.`", "122.48972675532002`", 
     "147.62034840275862`", "176.40661574209705`"},
    {"\<\"equity\"\>", "300.`", "322.48972675532`", "347.6203484027586`", 
     "376.4066157420971`"},
    {"\<\"\"\>", "\<\"\"\>", "", "", ""},
    {"\<\"balance\"\>", "0.`", "0.`", "0.`", "0.`"},
    {"\<\"\"\>", "\<\"\"\>", "", "", ""},
    {"\<\"CashFlow\"\>", "\<\"Year0\"\>", "\<\"Year1\"\>", "\<\"Year2\"\>", "\
\<\"Year3\"\>"},
    {"\<\"collections\"\>", "120.`", "162.`", "178.2`", "196.02`"},
    {"\<\"payments\"\>", "85.`", "83.5`", "91.85`", "101.035`"},
    {"\<\"interest\"\>", "5.`", 
     RowBox[{"-", "2.95636215805722`"}], 
     RowBox[{"-", "3.691776135538819`"}], 
     RowBox[{"-", "4.989478112395531`"}]},
    {"\<\"tax\"\>", "6.`", "19.276908647417166`", "21.540532840661644`", 
     "24.67394343371866`"},
    {"\<\"dividend\"\>", "7.`", "22.489726755320028`", "25.130621647438588`", 
     "28.786267339338437`"},
    {"\<\"newcapital\"\>", "0.`", "0.`", "0.`", "0.`"},
    {"\<\"newloan\"\>", "0.`", "0.`", "0.`", "0.`"},
    {"\<\"newassets\"\>", "50.`", "50.`", "21.2`", "22.64`"},
    {"\<\"cashflow\"\>", 
     RowBox[{"-", "33.`"}], 
     RowBox[{"-", "0.3164371914879567`"}], "23.755158582709722`", 
     "26.067654754478344`"},
    {"\<\"cash\"\>", "100.`", "99.68356280851205`", "123.43872139122176`", 
     "149.5063761457001`"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {Left}},
   GridBoxDividers->{
    "Rows" -> {
      False, True, False, False, False, False, False, False, False, False, 
       False, True, False, False, False, False, False, False, False, False, 
       False, False, False, False, False, False, False, False, False, False, 
       False, False, True}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.485162643567153*^9, 3.485162712542989*^9, 
  3.485163054764096*^9, 3.48520729078163*^9, 3.485673311648094*^9, 
  3.485674203820107*^9, 3.489370805312902*^9}]
}, Open  ]]
},
WindowSize->{845, 478},
WindowMargins->{{0, 179}, {230, 0}},
ShowSelection->True,
FrontEndVersion->"7.0 for Linux x86 (64-bit) (October 28, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 73702, 1592, 5005, "Input"],
Cell[74272, 1616, 624, 12, 24, "Message"],
Cell[74899, 1630, 430, 10, 24, "Print"],
Cell[75332, 1642, 4173, 82, 665, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
